modules

package
v0.2.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 8, 2026 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

const (
	AuthServerConfigPathVariableName = "AUTHSERVER_CONFIG_PATH"
)

Variables

This section is empty.

Functions

func ApplicationConfigurationModule

func ApplicationConfigurationModule(registry types.ServiceRegistry) error

ApplicationConfigurationModule configures and initializes the application settings.

func ApplicationServicesModule

func ApplicationServicesModule(registry types.ServiceRegistry) error

ApplicationServicesModule registers application services with the provided service registry.

func FiberModule

func FiberModule(registry types.ServiceRegistry) error

FiberModule registers a Fiber application and configuration to the provided service registry.

func LoggingModule

func LoggingModule(registry types.ServiceRegistry) error

LoggingModule registers the required logging services.

func RouteHandlersModule

func RouteHandlersModule(registry types.ServiceRegistry) error

RouteHandlersModule registers various route handlers in the provided service registry. It includes password, configuration, and public key handlers for route handling logic.

Types

This section is empty.

Jump to